mysql.exceptions.server

Package mysql :: Package exceptions :: Module server |
[hide private]
[frames] | no frames]

# Module server

source code

Exceptions from the MySQL server.

These are all errors that the server-side of the MySQL API may generate.

Because older clients may connect to newer versions of the server, the server may generate new errors that this client is not aware of. In this case, the exception mysql.exceptions.client.Unknown_Error is raised.

Classes | [hide private]
`` | Hashchk hashchk
`` | Nisamchk isamchk
`` | No NO
`` | Yes YES
`` | Cant_Create_File Can't create file '%s' (errno: %d)
`` | Cant_Create_Table Can't create table '%s' (errno: %d)
`` | Cant_Create_DB Can't create database '%s' (errno: %d)
`` | DB_Create_Exists Can't create database '%s'; database exists
`` | DB_Drop_Exists Can't drop database '%s'; database doesn't exist
`` | DB_Drop_Delete Error dropping database (can't delete '%s', errno: %d)
`` | DB_Drop_Rmdir Error dropping database (can't rmdir '%s', errno: %d)
`` | Cant_Delete_File Error on delete of '%s' (errno: %d)
`` | Cant_Find_System_Rec Can't read record in system table
`` | Cant_Get_Stat Can't get status of '%s' (errno: %d)
`` | Cant_Get_Wd Can't get working directory (errno: %d)
`` | Cant_Lock Can't lock file (errno: %d)
`` | Cant_Open_File Can't open file: '%s' (errno: %d)
`` | File_Not_Found Can't find file: '%s' (errno: %d)
`` | Cant_Read_Dir Can't read dir of '%s' (errno: %d)
`` | Cant_Set_Wd Can't change dir to '%s' (errno: %d)
`` | Checkread Record has changed since last read in table '%s'
`` | Disk_Full Disk full (%s); waiting for someone to free some space...
`` | Dup_Key Can't write; duplicate key in table '%s'
`` | Error_On_Close Error on close of '%s' (errno: %d)
`` | Error_On_Read Error reading file '%s' (errno: %d)
`` | Error_On_Rename Error on rename of '%s' to '%s' (errno: %d)
`` | Error_On_Write Error writing file '%s' (errno: %d)
`` | File_Used '%s' is locked against change
`` | Filsort_Abort Sort aborted
`` | Form_Not_Found View '%s' doesn't exist for '%s'
`` | Get_Errno Got error %d from storage engine
`` | Illegal_Ha Table storage engine for '%s' doesn't have this option
`` | Key_Not_Found Can't find record in '%s'
`` | Not_Form_File Incorrect information in file: '%s'
`` | Not_Keyfile Incorrect key file for table '%s'; try to repair it
`` | Old_Keyfile Old key file for table '%s'; repair it!
`` | Open_As_Readonly Table '%s' is read only
`` | Outofmemory Out of memory; restart server and try again (needed %d bytes)
`` | Out_Of_Sortmemory Out of sort memory; increase server sort buffer size
`` | Unexpected_Eof Unexpected EOF found when reading file '%s' (errno: %d)
`` | Con_Count_Error Too many connections
`` | Out_Of_Resources Out of memory; check if mysqld or some other process uses all available memory; if not, you may have to use 'ulimit' to allow mysqld to use more memory or you can add more swap space
`` | Bad_Host_Error Can't get hostname for your address
`` | Handshake_Error Bad handshake
`` | DB_Access_Denied_Error Access denied for user '%s'@'%s' to database '%s'
`` | Access_Denied_Error Access denied for user '%s'@'%s' (using password: %s)
`` | No_DB_Error No database selected
`` | Unknown_Com_Error Unknown command
`` | Bad_Null_Error Column '%s' cannot be null
`` | Bad_DB_Error Unknown database '%s'
`` | Table_Exists_Error Table '%s' already exists
`` | Bad_Table_Error Unknown table '%s'
`` | Non_Uniq_Error Column '%s' in %s is ambiguous
`` | Server_Shutdown Server shutdown in progress
`` | Bad_Field_Error Unknown column '%s' in '%s'
`` | Wrong_Field_With_Group '%s' isn't in GROUP BY
`` | Wrong_Group_Field Can't group on '%s'
`` | Wrong_Sum_Select Statement has sum functions and columns in same statement
`` | Wrong_Value_Count Column count doesn't match value count
`` | Too_Long_Ident Identifier name '%s' is too long
`` | Dup_Fieldname Duplicate column name '%s'
`` | Dup_Keyname Duplicate key name '%s'
`` | Dup_Entry Duplicate entry '%s' for key %d
`` | Wrong_Field_Spec Incorrect column specifier for column '%s'
`` | Parse_Error %s near '%s' at line %d
`` | Empty_Query Query was empty
`` | Nonuniq_Table Not unique table/alias: '%s'
`` | Invalid_Default Invalid default value for '%s'
`` | Multiple_Pri_Key Multiple primary key defined
`` | Too_Many_Keys Too many keys specified; max %d keys allowed
`` | Too_Many_Key_Parts Too many key parts specified; max %d parts allowed
`` | Too_Long_Key Specified key was too long; max key length is %d bytes
`` | Key_Column_Does_Not_Exits Key column '%s' doesn't exist in table
`` | Blob_Used_As_Key BLOB column '%s' can't be used in key specification with the used table type
`` | Too_Big_Fieldlength Column length too big for column '%s' (max = %d); use BLOB or TEXT instead
`` | Wrong_Auto_Key Incorrect table definition; there can be only one auto column and it must be defined as a key
`` | Ready %s: ready for connections.
`` | Normal_Shutdown %s: Normal shutdown
`` | Got_Signal %s: Got signal %d.
`` | Shutdown_Complete %s: Shutdown complete
`` | Forcing_Close %s: Forcing close of thread %ld user: '%s'
`` | Ipsock_Error Can't create IP socket
`` | No_Such_Index Table '%s' has no index like the one used in CREATE INDEX; recreate the table
`` | Wrong_Field_Terminators Field separator argument is not what is expected; check the manual
`` | Blobs_And_No_Terminated You can't use fixed rowlength with BLOBs; please use 'fields terminated by'
`` | Textfile_Not_Readable The file '%s' must be in the database directory or be readable by all
`` | File_Exists_Error File '%s' already exists
`` | Load_Info Records: %ld Deleted: %ld Skipped: %ld Warnings: %ld
`` | Alter_Info Records: %ld Duplicates: %ld
`` | Wrong_Sub_Key Incorrect sub part key; the used key part isn't a string, the used length is longer than the key part, or the storage engine doesn't support unique sub keys
`` | Cant_Remove_All_Fields You can't delete all columns with ALTER TABLE; use DROP TABLE instead
`` | Cant_Drop_Field_Or_Key Can't DROP '%s'; check that column/key exists
`` | Insert_Info Records: %ld Duplicates: %ld Warnings: %ld
`` | Update_Table_Used You can't specify target table '%s' for update in FROM clause
`` | No_Such_Thread Unknown thread id: %lu
`` | Kill_Denied_Error You are not owner of thread %lu
`` | No_Tables_Used No tables used
`` | Too_Big_Set Too many strings for column %s and SET
`` | No_Unique_Logfile Can't generate a unique log-filename %s.(1-999)
`` | Table_Not_Locked_For_Write Table '%s' was locked with a READ lock and can't be updated
`` | Table_Not_Locked Table '%s' was not locked with LOCK TABLES
`` | Blob_Cant_Have_Default BLOB/TEXT column '%s' can't have a default value
`` | Wrong_DB_Name Incorrect database name '%s'
`` | Wrong_Table_Name Incorrect table name '%s'
`` | Too_Big_Select The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay
`` | Unknown_Error Unknown error
`` | Unknown_Procedure Unknown procedure '%s'
`` | Wrong_Paramcount_To_Procedure Incorrect parameter count to procedure '%s'
`` | Wrong_Parameters_To_Procedure Incorrect parameters to procedure '%s'
`` | Unknown_Table Unknown table '%s' in %s
`` | Field_Specified_Twice Column '%s' specified twice
`` | Invalid_Group_Func_Use Invalid use of group function
`` | Unsupported_Extension Table '%s' uses an extension that doesn't exist in this MySQL version
`` | Table_Must_Have_Columns A table must have at least 1 column
`` | Record_File_Full The table '%s' is full
`` | Unknown_Character_Set Unknown character set: '%s'
`` | Too_Many_Tables Too many tables; MySQL can only use %d tables in a join
`` | Too_Many_Fields Too many columns
`` | Too_Big_Rowsize Row size too large.
`` | Stack_Overrun Thread stack overrun: Used: %ld of a %ld stack.
`` | Wrong_Outer_Join Cross dependency found in OUTER JOIN; examine your ON conditions
`` | Null_Column_In_Index Column '%s' is used with UNIQUE or INDEX but is not defined as NOT NULL
`` | Cant_Find_Udf Can't load function '%s'
`` | Cant_Initialize_Udf Can't initialize function '%s'; %s
`` | Udf_No_Paths No paths allowed for shared library
`` | Udf_Exists Function '%s' already exists
`` | Cant_Open_Library Can't open shared library '%s' (errno: %d %s)
`` | Cant_Find_Dl_Entry Can't find function '%s' in library'
`` | Function_Not_Defined Function '%s' is not defined
`` | Host_Is_Blocked Host '%s' is blocked because of many connection errors; unblock with 'mysqladmin flush-hosts'
`` | Host_Not_Privileged Host '%s' is not allowed to connect to this MySQL server
`` | Password_Anonymous_User You are using MySQL as an anonymous user and anonymous users are not allowed to change passwords
`` | Password_Not_Allowed You must have privileges to update tables in the mysql database to be able to change passwords for others
`` | Password_No_Match Can't find any matching row in the user table
`` | Update_Info Rows matched: %ld Changed: %ld Warnings: %ld
`` | Cant_Create_Thread Can't create a new thread (errno %d); if you are not out of available memory, you can consult the manual for a possible OS-dependent bug
`` | Wrong_Value_Count_On_Row Column count doesn't match value count at row %ld
`` | Cant_Reopen_Table Can't reopen table: '%s'
`` | Invalid_Use_Of_Null Invalid use of NULL value
`` | Regexp_Error Got error '%s' from regexp
`` | Mix_Of_Group_Func_And_Fields Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is illegal if there is no GROUP BY clause
`` | Nonexisting_Grant There is no such grant defined for user '%s' on host '%s'
`` | Tableaccess_Denied_Error %s command denied to user '%s'@'%s' for table '%s'
`` | Columnaccess_Denied_Error %s command denied to user '%s'@'%s' for column '%s' in table '%s'
`` | Illegal_Grant_For_Table Illegal GRANT/REVOKE command; please consult the manual to see which privileges can be used
`` | Grant_Wrong_Host_Or_User The host or user argument to GRANT is too long
`` | No_Such_Table Table '%s.%s' doesn't exist
`` | Nonexisting_Table_Grant There is no such grant defined for user '%s' on host '%s' on table '%s'
`` | Not_Allowed_Command The used command is not allowed with this MySQL version
`` | Syntax_Error You have an error in your SQL syntax; check the manual that corresponds to your MySQL server version for the right syntax to use
`` | Delayed_Cant_Change_Lock Delayed insert thread couldn't get requested lock for table %s
`` | Too_Many_Delayed_Threads Too many delayed threads in use
`` | Aborting_Connection Aborted connection %ld to db: '%s' user: '%s' (%s)
`` | Net_Packet_Too_Large Got a packet bigger than 'max_allowed_packet' bytes
`` | Net_Read_Error_From_Pipe Got a read error from the connection pipe
`` | Net_Fcntl_Error Got an error from fcntl()
`` | Net_Packets_Out_Of_Order Got packets out of order
`` | Net_Uncompress_Error Couldn't uncompress communication packet
`` | Net_Read_Error Got an error reading communication packets
`` | Net_Read_Interrupted Got timeout reading communication packets
`` | Net_Error_On_Write Got an error writing communication packets
`` | Net_Write_Interrupted Got timeout writing communication packets
`` | Too_Long_String Result string is longer than 'max_allowed_packet' bytes
`` | Table_Cant_Handle_Blob The used table type doesn't support BLOB/TEXT columns
`` | Table_Cant_Handle_Auto_Increment The used table type doesn't support AUTO_INCREMENT columns
`` | Delayed_Insert_Table_Locked INSERT DELAYED can't be used with table '%s' because it is locked with LOCK TABLES
`` | Wrong_Column_Name Incorrect column name '%s'
`` | Wrong_Key_Column The used storage engine can't index column '%s'
`` | Wrong_Mrg_Table All tables in the MERGE table are not identically defined
`` | Dup_Unique Can't write, because of unique constraint, to table '%s'
`` | Blob_Key_Without_Length BLOB/TEXT column '%s' used in key specification without a key length
`` | Primary_Cant_Have_Null All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use UNIQUE instead
`` | Too_Many_Rows Result consisted of more than one row
`` | Requires_Primary_Key This table type requires a primary key
`` | No_Raid_Compiled This version of MySQL is not compiled with RAID support
`` | Update_Without_Key_In_Safe_Mode You are using safe update mode and you tried to update a table without a WHERE that uses a KEY column
`` | Key_Does_Not_Exits Key '%s' doesn't exist in table '%s'
`` | Check_No_Such_Table Can't open table
`` | Check_Not_Implemented The storage engine for the table doesn't support %s
`` | Cant_Do_This_During_An_Transaction You are not allowed to execute this command in a transaction
`` | Error_During_Commit Got error %d during COMMIT
`` | Error_During_Rollback Got error %d during ROLLBACK
`` | Error_During_Flush_Logs Got error %d during FLUSH_LOGS
`` | Error_During_Checkpoint Got error %d during CHECKPOINT
`` | New_Aborting_Connection Aborted connection %ld to db: '%s' user: '%s' host: '%s' (%s)
`` | Dump_Not_Implemented The storage engine for the table does not support binary table dump
`` | Flush_Master_Binlog_Closed Binlog closed, cannot RESET MASTER
`` | Index_Rebuild Failed rebuilding the index of dumped table '%s'
`` | Master Error from master: '%s'
`` | Master_Net_Read Net error reading from master
`` | Master_Net_Write Net error writing to master
`` | Ft_Matching_Key_Not_Found Can't find FULLTEXT index matching the column list
`` | Lock_Or_Active_Transaction Can't execute the given command because you have active locked tables or an active transaction
`` | Unknown_System_Variable Unknown system variable '%s'
`` | Crashed_On_Usage Table '%s' is marked as crashed and should be repaired
`` | Crashed_On_Repair Table '%s' is marked as crashed and last (automatic?) repair failed
`` | Warning_Not_Complete_Rollback Some non-transactional changed tables couldn't be rolled back
`` | Trans_Cache_Full Multi-statement transaction required more than 'max_binlog_cache_size' bytes of storage; increase this mysqld variable and try again
`` | Slave_Must_Stop This operation cannot be performed with a running slave; run STOP SLAVE first
`` | Slave_Not_Running This operation requires a running slave; configure slave and do START SLAVE
`` | Bad_Slave The server is not configured as slave; fix in config file or with CHANGE MASTER TO
`` | Master_Info Could not initialize master info structure; more error messages can be found in the MySQL error log
`` | Slave_Thread Could not create slave thread; check system resources
`` | Too_Many_User_Connections User %s already has more than 'max_user_connections' active connections
`` | Set_Constants_Only You may only use constant expressions with SET
`` | Lock_Wait_Timeout Lock wait timeout exceeded; try restarting transaction
`` | Lock_Table_Full The total number of locks exceeds the lock table size
`` | Read_Only_Transaction Update locks cannot be acquired during a READ UNCOMMITTED transaction
`` | Drop_DB_With_Read_Lock DROP DATABASE not allowed while thread is holding global read lock
`` | Create_DB_With_Read_Lock CREATE DATABASE not allowed while thread is holding global read lock
`` | Wrong_Arguments Incorrect arguments to %s
`` | No_Permission_To_Create_User '%s'@'%s' is not allowed to create new users
`` | Union_Tables_In_Different_Dir Incorrect table definition; all MERGE tables must be in the same database
`` | Lock_Deadlock Deadlock found when trying to get lock; try restarting transaction
`` | Table_Cant_Handle_Ft The used table type doesn't support FULLTEXT indexes
`` | Cannot_Add_Foreign Cannot add foreign key constraint
`` | No_Referenced_Row Cannot add or update a child row: a foreign key constraint fails
`` | Row_Is_Referenced Cannot delete or update a parent row: a foreign key constraint fails
`` | Connect_To_Master Error connecting to master: %s
`` | Query_On_Master Error running query on master: %s
`` | Error_When_Executing_Command Error when executing command %s: %s
`` | Wrong_Usage Incorrect usage of %s and %s
`` | Wrong_Number_Of_Columns_In_Select The used SELECT statements have a different number of columns
`` | Cant_Update_With_Readlock Can't execute the query because you have a conflicting read lock
`` | Mixing_Not_Allowed Mixing of transactional and non-transactional tables is disabled
`` | Dup_Argument Option '%s' used twice in statement
`` | User_Limit_Reached User '%s' has exceeded the '%s' resource (current value: %ld)
`` | Specific_Access_Denied_Error Access denied; you need the %s privilege for this operation
`` | Local_Variable Variable '%s' is a SESSION variable and can't be used with SET GLOBAL
`` | Global_Variable Variable '%s' is a GLOBAL variable and should be set with SET GLOBAL
`` | No_Default Variable '%s' doesn't have a default value
`` | Wrong_Value_For_Var Variable '%s' can't be set to the value of '%s'
`` | Wrong_Type_For_Var Incorrect argument type to variable '%s'
`` | Var_Cant_Be_Read Variable '%s' can only be set, not read
`` | Cant_Use_Option_Here Incorrect usage/placement of '%s'
`` | Not_Supported_Yet This version of MySQL doesn't yet support '%s'
`` | Master_Fatal_Error_Reading_Binlog Got fatal error %d: '%s' from master when reading data from binary log
`` | Slave_Ignored_Table Slave SQL thread ignored the query because of replicate-*-table rules
`` | Incorrect_Global_Local_Var Variable '%s' is a %s variable
`` | Wrong_Fk_Def Incorrect foreign key definition for '%s': %s
`` | Key_Ref_Do_Not_Match_Table_Ref Key reference and table reference don't match
`` | Operand_Columns Operand should contain %d column(s)
`` | Subquery_No_1_Row Subquery returns more than 1 row
`` | Unknown_Stmt_Handler Unknown prepared statement handler (%.*s) given to %s
`` | Corrupt_Help_DB Help database is corrupt or does not exist
`` | Cyclic_Reference Cyclic reference on subqueries
`` | Auto_Convert Converting column '%s' from %s to %s
`` | Illegal_Reference Reference '%s' not supported (%s)
`` | Derived_Must_Have_Alias Every derived table must have its own alias
`` | Select_Reduced Select %u was reduced during optimization
`` | Tablename_Not_Allowed_Here Table '%s' from one of the SELECTs cannot be used in %s
`` | Not_Supported_Auth_Mode Client does not support authentication protocol requested by server; consider upgrading MySQL client
`` | Spatial_Cant_Have_Null All parts of a SPATIAL index must be NOT NULL
`` | Collation_Charset_Mismatch COLLATION '%s' is not valid for CHARACTER SET '%s'
`` | Slave_Was_Running Slave is already running
`` | Slave_Was_Not_Running Slave already has been stopped
`` | Too_Big_For_Uncompress Uncompressed data size too large; the maximum size is %d (probably, length of uncompressed data was corrupted)
`` | Zlib_Z_Mem_Error ZLIB: Not enough memory
`` | Zlib_Z_Buf_Error ZLIB: Not enough room in the output buffer (probably, length of uncompressed data was corrupted)
`` | Zlib_Z_Data_Error ZLIB: Input data corrupted
`` | Cut_Value_Group_Concat %d line(s) were cut by GROUP_CONCAT()
`` | Warn_Too_Few_Records Row %ld doesn't contain data for all columns
`` | Warn_Too_Many_Records Row %ld was truncated; it contained more data than there were input columns
`` | Warn_Null_To_Notnull Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld
`` | Warn_Data_Out_Of_Range Out of range value adjusted for column '%s' at row %ld
`` | Warn_Data_Truncated Data truncated for column '%s' at row %ld
`` | Warn_Using_Other_Handler Using storage engine %s for table '%s'
`` | Cant_Aggregate_2Collations Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'
`` | Drop_User Cannot drop one or more of the requested users
`` | Revoke_Grants Can't revoke all privileges, grant for one or more of the requested users
`` | Cant_Aggregate_3Collations Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'
`` | Cant_Aggregate_Ncollations Illegal mix of collations for operation '%s'
`` | Variable_Is_Not_Struct Variable '%s' is not a variable component (can't be used as XXXX.variable_name)
`` | Unknown_Collation Unknown collation: '%s'
`` | Slave_Ignored_Ssl_Params SSL parameters in CHANGE MASTER are ignored because this MySQL slave was compiled without SSL support; they can be used later if MySQL slave with SSL is started
`` | Server_Is_In_Secure_Auth_Mode Server is running in --secure-auth mode, but '%s'@'%s' has a password in the old format; please change the password to the new format
`` | Warn_Field_Resolved Field or reference '%s%s%s%s%s' of SELECT #%d was resolved in SELECT #%d
`` | Bad_Slave_Until_Cond Incorrect parameter or combination of parameters for START SLAVE UNTIL
`` | Missing_Skip_Slave It is recommended to use --skip-slave-start when doing step-by-step replication with START SLAVE UNTIL; otherwise, you will get problems if you get an unexpected slave's mysqld restart
`` | Until_Cond_Ignored SQL thread is not to be started so UNTIL options are ignored
`` | Wrong_Name_For_Index Incorrect index name '%s'
`` | Wrong_Name_For_Catalog Incorrect catalog name '%s'
`` | Warn_Qc_Resize Query cache failed to set size %lu; new query cache size is %lu
`` | Bad_Ft_Column Column '%s' cannot be part of FULLTEXT index
`` | Unknown_Key_Cache Unknown key cache '%s'
`` | Warn_Hostname_Wont_Work MySQL is started in --skip-name-resolve mode; you must restart it without this switch for this grant to work
`` | Unknown_Storage_Engine Unknown table engine '%s'
`` | Warn_Deprecated_Syntax '%s' is deprecated; use '%s' instead
`` | Non_Updatable_Table The target table %s of the %s is not updatable
`` | Feature_Disabled The '%s' feature is disabled; you need MySQL built with '%s' to have it working
`` | Option_Prevents_Statement The MySQL server is running with the %s option so it cannot execute this statement
`` | Duplicated_Value_In_Type Column '%s' has duplicated value '%s' in %s
`` | Truncated_Wrong_Value Truncated incorrect %s value: '%s'
`` | Too_Much_Auto_Timestamp_Cols Incorrect table definition; there can be only one TIMESTAMP column with CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause
`` | Invalid_On_Update Invalid ON UPDATE clause for '%s' column
`` | Unsupported_Ps This command is not supported in the prepared statement protocol yet
`` | Get_Errmsg Got error %d '%s' from %s
`` | Get_Temporary_Errmsg Got temporary error %d '%s' from %s
`` | Unknown_Time_Zone Unknown or incorrect time zone: '%s'
`` | Warn_Invalid_Timestamp Invalid TIMESTAMP value in column '%s' at row %ld
`` | Invalid_Character_String Invalid %s character string: '%s'
`` | Warn_Allowed_Packet_Overflowed Result of %s() was larger than max_allowed_packet (%ld) - truncated
`` | Conflicting_Declarations Conflicting declarations: '%s%s' and '%s%s'
`` | Sp_No_Recursive_Create Can't create a %s from within another stored routine
`` | Sp_Already_Exists %s %s already exists
`` | Sp_Does_Not_Exist %s %s does not exist
`` | Sp_Drop_Failed Failed to DROP %s %s
`` | Sp_Store_Failed Failed to CREATE %s %s
`` | Sp_Lilabel_Mismatch %s with no matching label: %s
`` | Sp_Label_Redefine Redefining label %s
`` | Sp_Label_Mismatch End-label %s without match
`` | Sp_Uninit_Var Referring to uninitialized variable %s
`` | Sp_Badselect PROCEDURE %s can't return a result set in the given context
`` | Sp_Badreturn RETURN is only allowed in a FUNCTION
`` | Sp_Badstatement %s is not allowed in stored procedures
`` | Update_Log_Deprecated_Ignored The update log is deprecated and replaced by the binary log; SET SQL_LOG_UPDATE has been ignored
`` | Update_Log_Deprecated_Translated The update log is deprecated and replaced by the binary log; SET SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN
`` | Query_Interrupted Query execution was interrupted
`` | Sp_Wrong_No_Of_Args Incorrect number of arguments for %s %s; expected %u, got %u
`` | Sp_Cond_Mismatch Undefined CONDITION: %s
`` | Sp_Noreturn No RETURN found in FUNCTION %s
`` | Sp_Noreturnend FUNCTION %s ended without RETURN
`` | Sp_Bad_Cursor_Query Cursor statement must be a SELECT
`` | Sp_Bad_Cursor_Select Cursor SELECT must not have INTO
`` | Sp_Cursor_Mismatch Undefined CURSOR: %s
`` | Sp_Cursor_Already_Open Cursor is already open
`` | Sp_Cursor_Not_Open Cursor is not open
`` | Sp_Undeclared_Var Undeclared variable: %s
`` | Sp_Wrong_No_Of_Fetch_Args Incorrect number of FETCH variables
`` | Sp_Fetch_No_Data No data to FETCH
`` | Sp_Dup_Param Duplicate parameter: %s
`` | Sp_Dup_Var Duplicate variable: %s
`` | Sp_Dup_Cond Duplicate condition: %s
`` | Sp_Dup_Curs Duplicate cursor: %s
`` | Sp_Cant_Alter Failed to ALTER %s %s
`` | Sp_Subselect_Nyi Subselect value not supported
`` | Stmt_Not_Allowed_In_Sf_Or_Trg %s is not allowed in stored function or trigger
`` | Sp_Varcond_After_Curshndlr Variable or condition declaration after cursor or handler declaration
`` | Sp_Cursor_After_Handler Cursor declaration after handler declaration
`` | Sp_Case_Not_Found Case not found for CASE statement
`` | Fparser_Too_Big_File Configuration file '%s' is too big
`` | Fparser_Bad_Header Malformed file type header in file '%s'
`` | Fparser_Eof_In_Comment Unexpected end of file while parsing comment '%s'
`` | Fparser_Error_In_Parameter Error while parsing parameter '%s' (line: '%s')
`` | Fparser_Eof_In_Unknown_Parameter Unexpected end of file while skipping unknown parameter '%s'
`` | View_No_Explain EXPLAIN/SHOW can not be issued; lacking privileges for underlying table
`` | Frm_Unknown_Type File '%s' has unknown type '%s' in its header
`` | Wrong_Object '%s.%s' is not %s
`` | Nonupdateable_Column Column '%s' is not updatable
`` | View_Select_Derived View's SELECT contains a subquery in the FROM clause
`` | View_Select_Clause View's SELECT contains a '%s' clause
`` | View_Select_Variable View's SELECT contains a variable or parameter
`` | View_Select_Tmptable View's SELECT refers to a temporary table '%s'
`` | View_Wrong_List View's SELECT and view's field list have different column counts
`` | Warn_View_Merge View merge algorithm can't be used here for now (assumed undefined algorithm)
`` | Warn_View_Without_Key View being updated does not have complete key of underlying table in it
`` | View_Invalid View '%s.%s' references invalid table(s) or column(s) or function(s) or definer/invoker of view lack rights to use them
`` | Sp_No_Drop_Sp Can't drop or alter a %s from within another stored routine
`` | Sp_Goto_In_Hndlr GOTO is not allowed in a stored procedure handler
`` | Trg_Already_Exists Trigger already exists
`` | Trg_Does_Not_Exist Trigger does not exist
`` | Trg_On_View_Or_Temp_Table Trigger's '%s' is view or temporary table
`` | Trg_Cant_Change_Row Updating of %s row is not allowed in %strigger
`` | Trg_No_Such_Row_In_Trg There is no %s row in %s trigger
`` | No_Default_For_Field Field '%s' doesn't have a default value
`` | Division_By_Zero Division by 0
`` | Truncated_Wrong_Value_For_Field Incorrect %s value: '%s' for column '%s' at row %ld
`` | Illegal_Value_For_Type Illegal %s '%s' value found during parsing
`` | View_Nonupd_Check CHECK OPTION on non-updatable view '%s.%s'
`` | View_Check_Failed CHECK OPTION failed '%s.%s'
`` | Procaccess_Denied_Error %s command denied to user '%s'@'%s' for routine '%s'
`` | Relay_Log_Fail Failed purging old relay logs: %s
`` | Passwd_Length Password hash should be a %d-digit hexadecimal number
`` | Unknown_Target_Binlog Target log not found in binlog index
`` | Io_Err_Log_Index_Read I/O error reading log index file
`` | Binlog_Purge_Prohibited Server configuration does not permit binlog purge
`` | Fseek_Fail Failed on fseek()
`` | Binlog_Purge_Fatal_Err Fatal error during log purge
`` | Log_In_Use A purgeable log is in use, will not purge
`` | Log_Purge_Unknown_Err Unknown error during log purge
`` | Relay_Log_Init Failed initializing relay log position: %s
`` | No_Binary_Logging You are not using binary logging
`` | Reserved_Syntax The '%s' syntax is reserved for purposes internal to the MySQL server
`` | Wsas_Failed WSAStartup Failed
`` | Diff_Groups_Proc Can't handle procedures with differents groups yet
`` | No_Group_For_Proc Select must have a group with this procedure
`` | Order_With_Proc Can't use ORDER clause with this procedure
`` | Logging_Prohibit_Changing_Of Binary logging and replication forbid changing the global server %s
`` | No_File_Mapping Can't map file: %s, errno: %d
`` | Wrong_Magic Wrong magic in %s
`` | Ps_Many_Param Prepared statement contains too many placeholders
`` | Key_Part_0 Key part '%s' length cannot be 0
`` | View_Checksum View text checksum failed
`` | View_Multiupdate Can not modify more than one base table through a join view '%s.%s'
`` | View_No_Insert_Field_List Can not insert into join view '%s.%s' without fields list
`` | View_Delete_Merge_View Can not delete from join view '%s.%s'
`` | Cannot_User Operation %s failed for %s
`` | Xaer_Nota XAER_NOTA: Unknown XID
`` | Xaer_Inval XAER_INVAL: Invalid arguments (or unsupported command)
`` | Xaer_Rmfail XAER_RMFAIL: The command cannot be executed when global transaction is in the %s state
`` | Xaer_Outside XAER_OUTSIDE: Some work is done outside global transaction
`` | Xaer_Rmerr XAER_RMERR: Fatal error occurred in the transaction branch - check your data for consistency
`` | Xa_Rbrollback XA_RBROLLBACK: Transaction branch was rolled back
`` | Nonexisting_Proc_Grant There is no such grant defined for user '%s' on host '%s' on routine '%s'
`` | Proc_Auto_Grant_Fail Failed to grant EXECUTE and ALTER ROUTINE privileges
`` | Proc_Auto_Revoke_Fail Failed to revoke all privileges to dropped routine
`` | Data_Too_Long Data too long for column '%s' at row %ld
`` | Sp_Bad_Sqlstate Bad SQLSTATE: '%s'
`` | Startup %s: ready for connections.
`` | Load_From_Fixed_Size_Rows_To_Var Can't load value from file with fixed size rows to variable
`` | Cant_Create_User_With_Grant You are not allowed to create a user with GRANT
`` | Wrong_Value_For_Type Incorrect %s value: '%s' for function %s
`` | Table_Def_Changed Table definition has changed, please retry transaction
`` | Sp_Dup_Handler Duplicate handler declared in the same block
`` | Sp_Not_Var_Arg OUT or INOUT argument %d for routine %s is not a variable
`` | Sp_No_Retset Not allowed to return a result set from a %s
`` | Cant_Create_Geometry_Object Cannot get geometry object from data you send to the GEOMETRY field
`` | Failed_Routine_Break_Binlog A routine failed and has neither NO SQL nor READS SQL DATA in its declaration and binary logging is enabled; if non-transactional tables were updated, the binary log will miss their changes
`` | Binlog_Unsafe_Routine This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its declaration and binary logging is enabled (you might want to use the less safe log_bin_trust_function_creators variable)
`` | Binlog_Create_Routine_Need_Super You do not have the SUPER privilege and binary logging is enabled (you might want to use the less safe log_bin_trust_function_creators variable)
`` | Exec_Stmt_With_Open_Cursor You can't execute a prepared statement which has an open cursor associated with it.
`` | Stmt_Has_No_Open_Cursor The statement (%lu) has no open cursor.
`` | Commit_Not_Allowed_In_Sf_Or_Trg Explicit or implicit commit is not allowed in stored function or trigger.
`` | No_Default_For_View_Field Field of view '%s.%s' underlying table doesn't have a default value
`` | Sp_No_Recursion Recursive stored routines are not allowed.
`` | Too_Big_Scale Too big scale %d specified for column '%s'.
`` | Too_Big_Precision Too big precision %d specified for column '%s'.
`` | M_Bigger_Than_D For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column '%s').
`` | Wrong_Lock_Of_System_Table You can't combine write-locking of system '%s.%s' table with other tables
`` | Connect_To_Foreign_Data_Source Unable to connect to foreign data source - database '%s'!
`` | Query_On_Foreign_Data_Source There was a problem processing the query on the foreign data source.
`` | Foreign_Data_Source_Doesnt_Exist The foreign data source you are trying to reference does not exist.
`` | Foreign_Data_String_Invalid_Cant_Create Can't create federated table.
`` | Foreign_Data_String_Invalid The data source connection string '%s' is not in the correct format
`` | Cant_Create_Federated_Table Can't create federated table.
`` | Trg_In_Wrong_Schema Trigger in wrong schema
`` | Stack_Overrun_Need_More Thread stack overrun: %ld bytes used of a %ld byte stack, and %ld bytes needed.
`` | Too_Long_Body Routine body for '%s' is too long
`` | Warn_Cant_Drop_Default_Keycache Cannot drop default keycache
`` | Too_Big_Displaywidth Display width out of range for column '%s' (max = %d)
`` | Xaer_Dupid XAER_DUPID: The XID already exists
`` | Datetime_Function_Overflow Datetime function: %s field overflow
`` | Cant_Update_Used_Table_In_Sf_Or_Trg Can't update table '%s' in stored function/trigger because it is already used by statement which invoked this stored function/trigger.
`` | View_Prevent_Update The definition of table '%s' prevents operation %s on table '%s'.
`` | Ps_No_Recursion The prepared statement contains a stored routine call that refers to that same statement.
`` | Sp_Cant_Set_Autocommit Not allowed to set autocommit from a stored function or trigger
`` | No_View_User View definer is not fully qualified
`` | View_Frm_No_User View %s.%s has not definer information (old table format).
`` | View_Other_User You need the SUPER privilege for creation view with %s@%s definer
`` | No_Such_User There is no '%s'@'%s' registered
`` | Forbid_Schema_Change Changing schema from '%s' to '%s' is not allowed.
`` | Row_Is_Referenced_2 Cannot delete or update a parent row: a foreign key constraint fails (%s)
`` | No_Referenced_Row_2 Cannot add or update a child row: a foreign key constraint fails (%s)
`` | Sp_Bad_Var_Shadow Variable '%s' must be quoted with `...`, or renamed
`` | Sp_Recursion_Limit Recursive limit %d (as set by the max_sp_recursion_depth variable) was exceeded for routine %.64s
`` | Malformed_Definer Definer is not fully qualified
`` | Old_File_Format '%-.64s' has an old format, you should re-create the '%s' object(s).
`` | Trg_No_Definer No definer attribute for trigger '%-.64s'.'%-.64s'.
`` | Sp_Proc_Table_Corrupt Failed to load routine %s.
`` | Table_Needs_Upgrade Table upgrade required.
`` | Sp_No_Aggregate AGGREGATE is not supported for stored functions
`` | Sp_Wrong_Name Incorrect routine name '%-.64s'
`` | Max_Prepared_Stmt_Count_Reached Can't create more than max_prepared_stmt_count statements (current value: %lu)
`` | View_Recursive `%-.64s`.``%-.64s`` contains view recursion.
`` | Non_Grouping_Field_Used non-grouping field '%-.64s' is used in %-.64s clause
`` | Table_Cant_Handle_Spkeys The used table type doesn't support SPATIAL indexes
`` | No_Triggers_On_System_Schema Triggers can not be created on system tables
`` | Username user name?
`` | Hostname host name?
`` | Wrong_String_Length String '%-.70s' is too long for %s (should be no longer than %d)
`` | Removed_Spaces Leading spaces are removed from name '%s'
`` | Autoinc_Read_Failed Failed to read auto-increment value from storage engine
`` | Non_Insertable_Table The target table %-.100s of the %s is not insertable-into

Variables | [hide private]
`` | __version__ = `'$Revision: 1.5 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.5 $'